==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkGPUVolumeRayCastMapper.java <==
// java wrapper for vtkGPUVolumeRayCastMapper object
//

package vtk;
import vtk.*;

public class vtkGPUVolumeRayCastMapper extends vtkVolumeMapper
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetAutoAdjustSampleDistances_2(int id0);
  public void SetAutoAdjustSampleDistances(int id0)
    { SetAutoAdjustSampleDistances_2(id0); }

  private native int GetAutoAdjustSampleDistancesMinValue_3();
  public int GetAutoAdjustSampleDistancesMinValue()
    { return GetAutoAdjustSampleDistancesMinValue_3(); }

  private native int GetAutoAdjustSampleDistancesMaxValue_4();
  public int GetAutoAdjustSampleDistancesMaxValue()
    { return GetAutoAdjustSampleDistancesMaxValue_4(); }

  private native int GetAutoAdjustSampleDistances_5();
  public int GetAutoAdjustSampleDistances()
    { return GetAutoAdjustSampleDistances_5(); }

  private native void AutoAdjustSampleDistancesOn_6();
  public void AutoAdjustSampleDistancesOn()
    { AutoAdjustSampleDistancesOn_6(); }

  private native void AutoAdjustSampleDistancesOff_7();
  public void AutoAdjustSampleDistancesOff()
    { AutoAdjustSampleDistancesOff_7(); }

  private native void SetLockSampleDistanceToInputSpacing_8(int id0);
  public void SetLockSampleDistanceToInputSpacing(int id0)
    { SetLockSampleDistanceToInputSpacing_8(id0); }

  private native int GetLockSampleDistanceToInputSpacingMinValue_9();
  public int GetLockSampleDistanceToInputSpacingMinValue()
    { return GetLockSampleDistanceToInputSpacingMinValue_9(); }

  private native int GetLockSampleDistanceToInputSpacingMaxValue_10();
  public int GetLockSampleDistanceToInputSpacingMaxValue()
    { return GetLockSampleDistanceToInputSpacingMaxValue_10(); }

  private native int GetLockSampleDistanceToInputSpacing_11();
  public int GetLockSampleDistanceToInputSpacing()
    { return GetLockSampleDistanceToInputSpacing_11(); }

  private native void LockSampleDistanceToInputSpacingOn_12();
  public void LockSampleDistanceToInputSpacingOn()
    { LockSampleDistanceToInputSpacingOn_12(); }

  private native void LockSampleDistanceToInputSpacingOff_13();
  public void LockSampleDistanceToInputSpacingOff()
    { LockSampleDistanceToInputSpacingOff_13(); }

  private native void SetUseJittering_14(int id0);
  public void SetUseJittering(int id0)
    { SetUseJittering_14(id0); }

  private native int GetUseJitteringMinValue_15();
  public int GetUseJitteringMinValue()
    { return GetUseJitteringMinValue_15(); }

  private native int GetUseJitteringMaxValue_16();
  public int GetUseJitteringMaxValue()
    { return GetUseJitteringMaxValue_16(); }

  private native int GetUseJittering_17();
  public int GetUseJittering()
    { return GetUseJittering_17(); }

  private native void UseJitteringOn_18();
  public void UseJitteringOn()
    { UseJitteringOn_18(); }

  private native void UseJitteringOff_19();
  public void UseJitteringOff()
    { UseJitteringOff_19(); }

  private native void SetUseDepthPass_20(int id0);
  public void SetUseDepthPass(int id0)
    { SetUseDepthPass_20(id0); }

  private native int GetUseDepthPassMinValue_21();
  public int GetUseDepthPassMinValue()
    { return GetUseDepthPassMinValue_21(); }

  private native int GetUseDepthPassMaxValue_22();
  public int GetUseDepthPassMaxValue()
    { return GetUseDepthPassMaxValue_22(); }

  private native int GetUseDepthPass_23();
  public int GetUseDepthPass()
    { return GetUseDepthPass_23(); }

  private native void UseDepthPassOn_24();
  public void UseDepthPassOn()
    { UseDepthPassOn_24(); }

  private native void UseDepthPassOff_25();
  public void UseDepthPassOff()
    { UseDepthPassOff_25(); }

  private native long GetDepthPassContourValues_26();
  public vtkContourValues GetDepthPassContourValues() {
    long temp = GetDepthPassContourValues_26();

    if (temp == 0) return null;
    return (vtkContourValues)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSampleDistance_27(double id0);
  public void SetSampleDistance(double id0)
    { SetSampleDistance_27(id0); }

  private native double GetSampleDistance_28();
  public double GetSampleDistance()
    { return GetSampleDistance_28(); }

  private native void SetImageSampleDistance_29(double id0);
  public void SetImageSampleDistance(double id0)
    { SetImageSampleDistance_29(id0); }

  private native double GetImageSampleDistanceMinValue_30();
  public double GetImageSampleDistanceMinValue()
    { return GetImageSampleDistanceMinValue_30(); }

  private native double GetImageSampleDistanceMaxValue_31();
  public double GetImageSampleDistanceMaxValue()
    { return GetImageSampleDistanceMaxValue_31(); }

  private native double GetImageSampleDistance_32();
  public double GetImageSampleDistance()
    { return GetImageSampleDistance_32(); }

  private native void SetMinimumImageSampleDistance_33(double id0);
  public void SetMinimumImageSampleDistance(double id0)
    { SetMinimumImageSampleDistance_33(id0); }

  private native double GetMinimumImageSampleDistanceMinValue_34();
  public double GetMinimumImageSampleDistanceMinValue()
    { return GetMinimumImageSampleDistanceMinValue_34(); }

  private native double GetMinimumImageSampleDistanceMaxValue_35();
  public double GetMinimumImageSampleDistanceMaxValue()
    { return GetMinimumImageSampleDistanceMaxValue_35(); }

  private native double GetMinimumImageSampleDistance_36();
  public double GetMinimumImageSampleDistance()
    { return GetMinimumImageSampleDistance_36(); }

  private native void SetMaximumImageSampleDistance_37(double id0);
  public void SetMaximumImageSampleDistance(double id0)
    { SetMaximumImageSampleDistance_37(id0); }

  private native double GetMaximumImageSampleDistanceMinValue_38();
  public double GetMaximumImageSampleDistanceMinValue()
    { return GetMaximumImageSampleDistanceMinValue_38(); }

  private native double GetMaximumImageSampleDistanceMaxValue_39();
  public double GetMaximumImageSampleDistanceMaxValue()
    { return GetMaximumImageSampleDistanceMaxValue_39(); }

  private native double GetMaximumImageSampleDistance_40();
  public double GetMaximumImageSampleDistance()
    { return GetMaximumImageSampleDistance_40(); }

  private native void SetFinalColorWindow_41(double id0);
  public void SetFinalColorWindow(double id0)
    { SetFinalColorWindow_41(id0); }

  private native double GetFinalColorWindow_42();
  public double GetFinalColorWindow()
    { return GetFinalColorWindow_42(); }

  private native void SetFinalColorLevel_43(double id0);
  public void SetFinalColorLevel(double id0)
    { SetFinalColorLevel_43(id0); }

  private native double GetFinalColorLevel_44();
  public double GetFinalColorLevel()
    { return GetFinalColorLevel_44(); }

  private native void SetMaxMemoryInBytes_45(int id0);
  public void SetMaxMemoryInBytes(int id0)
    { SetMaxMemoryInBytes_45(id0); }

  private native int GetMaxMemoryInBytes_46();
  public int GetMaxMemoryInBytes()
    { return GetMaxMemoryInBytes_46(); }

  private native void SetMaxMemoryFraction_47(double id0);
  public void SetMaxMemoryFraction(double id0)
    { SetMaxMemoryFraction_47(id0); }

  private native double GetMaxMemoryFractionMinValue_48();
  public double GetMaxMemoryFractionMinValue()
    { return GetMaxMemoryFractionMinValue_48(); }

  private native double GetMaxMemoryFractionMaxValue_49();
  public double GetMaxMemoryFractionMaxValue()
    { return GetMaxMemoryFractionMaxValue_49(); }

  private native double GetMaxMemoryFraction_50();
  public double GetMaxMemoryFraction()
    { return GetMaxMemoryFraction_50(); }

  private native void SetReportProgress_51(boolean id0);
  public void SetReportProgress(boolean id0)
    { SetReportProgress_51(id0); }

  private native boolean GetReportProgress_52();
  public boolean GetReportProgress()
    { return GetReportProgress_52(); }

  private native int IsRenderSupported_53(vtkRenderWindow id0,vtkVolumeProperty id1);
  public int IsRenderSupported(vtkRenderWindow id0,vtkVolumeProperty id1)
    { return IsRenderSupported_53(id0,id1); }

  private native void CreateCanonicalView_54(vtkRenderer id0,vtkVolume id1,vtkImageData id2,int id3,double id4[],double id5[]);
  public void CreateCanonicalView(vtkRenderer id0,vtkVolume id1,vtkImageData id2,int id3,double id4[],double id5[])
    { CreateCanonicalView_54(id0,id1,id2,id3,id4,id5); }

  private native void SetMaskInput_55(vtkImageData id0);
  public void SetMaskInput(vtkImageData id0)
    { SetMaskInput_55(id0); }

  private native long GetMaskInput_56();
  public vtkImageData GetMaskInput() {
    long temp = GetMaskInput_56();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetMaskType_57(int id0);
  public void SetMaskType(int id0)
    { SetMaskType_57(id0); }

  private native int GetMaskType_58();
  public int GetMaskType()
    { return GetMaskType_58(); }

  private native void SetMaskTypeToBinary_59();
  public void SetMaskTypeToBinary()
    { SetMaskTypeToBinary_59(); }

  private native void SetMaskTypeToLabelMap_60();
  public void SetMaskTypeToLabelMap()
    { SetMaskTypeToLabelMap_60(); }

  private native void SetMaskBlendFactor_61(double id0);
  public void SetMaskBlendFactor(double id0)
    { SetMaskBlendFactor_61(id0); }

  private native double GetMaskBlendFactorMinValue_62();
  public double GetMaskBlendFactorMinValue()
    { return GetMaskBlendFactorMinValue_62(); }

  private native double GetMaskBlendFactorMaxValue_63();
  public double GetMaskBlendFactorMaxValue()
    { return GetMaskBlendFactorMaxValue_63(); }

  private native double GetMaskBlendFactor_64();
  public double GetMaskBlendFactor()
    { return GetMaskBlendFactor_64(); }

  private native void SetRenderToImage_65(int id0);
  public void SetRenderToImage(int id0)
    { SetRenderToImage_65(id0); }

  private native int GetRenderToImage_66();
  public int GetRenderToImage()
    { return GetRenderToImage_66(); }

  private native void RenderToImageOn_67();
  public void RenderToImageOn()
    { RenderToImageOn_67(); }

  private native void RenderToImageOff_68();
  public void RenderToImageOff()
    { RenderToImageOff_68(); }

  private native void SetDepthImageScalarType_69(int id0);
  public void SetDepthImageScalarType(int id0)
    { SetDepthImageScalarType_69(id0); }

  private native int GetDepthImageScalarType_70();
  public int GetDepthImageScalarType()
    { return GetDepthImageScalarType_70(); }

  private native void SetDepthImageScalarTypeToUnsignedChar_71();
  public void SetDepthImageScalarTypeToUnsignedChar()
    { SetDepthImageScalarTypeToUnsignedChar_71(); }

  private native void SetDepthImageScalarTypeToUnsignedShort_72();
  public void SetDepthImageScalarTypeToUnsignedShort()
    { SetDepthImageScalarTypeToUnsignedShort_72(); }

  private native void SetDepthImageScalarTypeToFloat_73();
  public void SetDepthImageScalarTypeToFloat()
    { SetDepthImageScalarTypeToFloat_73(); }

  private native void SetClampDepthToBackface_74(int id0);
  public void SetClampDepthToBackface(int id0)
    { SetClampDepthToBackface_74(id0); }

  private native int GetClampDepthToBackface_75();
  public int GetClampDepthToBackface()
    { return GetClampDepthToBackface_75(); }

  private native void ClampDepthToBackfaceOn_76();
  public void ClampDepthToBackfaceOn()
    { ClampDepthToBackfaceOn_76(); }

  private native void ClampDepthToBackfaceOff_77();
  public void ClampDepthToBackfaceOff()
    { ClampDepthToBackfaceOff_77(); }

  private native void GetDepthImage_78(vtkImageData id0);
  public void GetDepthImage(vtkImageData id0)
    { GetDepthImage_78(id0); }

  private native void GetColorImage_79(vtkImageData id0);
  public void GetColorImage(vtkImageData id0)
    { GetColorImage_79(id0); }

  private native void Render_80(vtkRenderer id0,vtkVolume id1);
  public void Render(vtkRenderer id0,vtkVolume id1)
    { Render_80(id0,id1); }

  private native void GPURender_81(vtkRenderer id0,vtkVolume id1);
  public void GPURender(vtkRenderer id0,vtkVolume id1)
    { GPURender_81(id0,id1); }

  private native void ReleaseGraphicsResources_82(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_82(id0); }

  private native void GetReductionRatio_83(double id0[]);
  public void GetReductionRatio(double id0[])
    { GetReductionRatio_83(id0); }

  public vtkGPUVolumeRayCastMapper() { super(); }

  public vtkGPUVolumeRayCastMapper(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-4-armv7h.pkg.tar.xz: vtk/vtkGPUVolumeRayCastMapper.java <==
// java wrapper for vtkGPUVolumeRayCastMapper object
//

package vtk;
import vtk.*;

public class vtkGPUVolumeRayCastMapper extends vtkVolumeMapper
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetAutoAdjustSampleDistances_2(int id0);
  public void SetAutoAdjustSampleDistances(int id0)
    { SetAutoAdjustSampleDistances_2(id0); }

  private native int GetAutoAdjustSampleDistancesMinValue_3();
  public int GetAutoAdjustSampleDistancesMinValue()
    { return GetAutoAdjustSampleDistancesMinValue_3(); }

  private native int GetAutoAdjustSampleDistancesMaxValue_4();
  public int GetAutoAdjustSampleDistancesMaxValue()
    { return GetAutoAdjustSampleDistancesMaxValue_4(); }

  private native int GetAutoAdjustSampleDistances_5();
  public int GetAutoAdjustSampleDistances()
    { return GetAutoAdjustSampleDistances_5(); }

  private native void AutoAdjustSampleDistancesOn_6();
  public void AutoAdjustSampleDistancesOn()
    { AutoAdjustSampleDistancesOn_6(); }

  private native void AutoAdjustSampleDistancesOff_7();
  public void AutoAdjustSampleDistancesOff()
    { AutoAdjustSampleDistancesOff_7(); }

  private native void SetLockSampleDistanceToInputSpacing_8(int id0);
  public void SetLockSampleDistanceToInputSpacing(int id0)
    { SetLockSampleDistanceToInputSpacing_8(id0); }

  private native int GetLockSampleDistanceToInputSpacingMinValue_9();
  public int GetLockSampleDistanceToInputSpacingMinValue()
    { return GetLockSampleDistanceToInputSpacingMinValue_9(); }

  private native int GetLockSampleDistanceToInputSpacingMaxValue_10();
  public int GetLockSampleDistanceToInputSpacingMaxValue()
    { return GetLockSampleDistanceToInputSpacingMaxValue_10(); }

  private native int GetLockSampleDistanceToInputSpacing_11();
  public int GetLockSampleDistanceToInputSpacing()
    { return GetLockSampleDistanceToInputSpacing_11(); }

  private native void LockSampleDistanceToInputSpacingOn_12();
  public void LockSampleDistanceToInputSpacingOn()
    { LockSampleDistanceToInputSpacingOn_12(); }

  private native void LockSampleDistanceToInputSpacingOff_13();
  public void LockSampleDistanceToInputSpacingOff()
    { LockSampleDistanceToInputSpacingOff_13(); }

  private native void SetUseJittering_14(int id0);
  public void SetUseJittering(int id0)
    { SetUseJittering_14(id0); }

  private native int GetUseJitteringMinValue_15();
  public int GetUseJitteringMinValue()
    { return GetUseJitteringMinValue_15(); }

  private native int GetUseJitteringMaxValue_16();
  public int GetUseJitteringMaxValue()
    { return GetUseJitteringMaxValue_16(); }

  private native int GetUseJittering_17();
  public int GetUseJittering()
    { return GetUseJittering_17(); }

  private native void UseJitteringOn_18();
  public void UseJitteringOn()
    { UseJitteringOn_18(); }

  private native void UseJitteringOff_19();
  public void UseJitteringOff()
    { UseJitteringOff_19(); }

  private native void SetUseDepthPass_20(int id0);
  public void SetUseDepthPass(int id0)
    { SetUseDepthPass_20(id0); }

  private native int GetUseDepthPassMinValue_21();
  public int GetUseDepthPassMinValue()
    { return GetUseDepthPassMinValue_21(); }

  private native int GetUseDepthPassMaxValue_22();
  public int GetUseDepthPassMaxValue()
    { return GetUseDepthPassMaxValue_22(); }

  private native int GetUseDepthPass_23();
  public int GetUseDepthPass()
    { return GetUseDepthPass_23(); }

  private native void UseDepthPassOn_24();
  public void UseDepthPassOn()
    { UseDepthPassOn_24(); }

  private native void UseDepthPassOff_25();
  public void UseDepthPassOff()
    { UseDepthPassOff_25(); }

  private native long GetDepthPassContourValues_26();
  public vtkContourValues GetDepthPassContourValues() {
    long temp = GetDepthPassContourValues_26();

    if (temp == 0) return null;
    return (vtkContourValues)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSampleDistance_27(double id0);
  public void SetSampleDistance(double id0)
    { SetSampleDistance_27(id0); }

  private native double GetSampleDistance_28();
  public double GetSampleDistance()
    { return GetSampleDistance_28(); }

  private native void SetImageSampleDistance_29(double id0);
  public void SetImageSampleDistance(double id0)
    { SetImageSampleDistance_29(id0); }

  private native double GetImageSampleDistanceMinValue_30();
  public double GetImageSampleDistanceMinValue()
    { return GetImageSampleDistanceMinValue_30(); }

  private native double GetImageSampleDistanceMaxValue_31();
  public double GetImageSampleDistanceMaxValue()
    { return GetImageSampleDistanceMaxValue_31(); }

  private native double GetImageSampleDistance_32();
  public double GetImageSampleDistance()
    { return GetImageSampleDistance_32(); }

  private native void SetMinimumImageSampleDistance_33(double id0);
  public void SetMinimumImageSampleDistance(double id0)
    { SetMinimumImageSampleDistance_33(id0); }

  private native double GetMinimumImageSampleDistanceMinValue_34();
  public double GetMinimumImageSampleDistanceMinValue()
    { return GetMinimumImageSampleDistanceMinValue_34(); }

  private native double GetMinimumImageSampleDistanceMaxValue_35();
  public double GetMinimumImageSampleDistanceMaxValue()
    { return GetMinimumImageSampleDistanceMaxValue_35(); }

  private native double GetMinimumImageSampleDistance_36();
  public double GetMinimumImageSampleDistance()
    { return GetMinimumImageSampleDistance_36(); }

  private native void SetMaximumImageSampleDistance_37(double id0);
  public void SetMaximumImageSampleDistance(double id0)
    { SetMaximumImageSampleDistance_37(id0); }

  private native double GetMaximumImageSampleDistanceMinValue_38();
  public double GetMaximumImageSampleDistanceMinValue()
    { return GetMaximumImageSampleDistanceMinValue_38(); }

  private native double GetMaximumImageSampleDistanceMaxValue_39();
  public double GetMaximumImageSampleDistanceMaxValue()
    { return GetMaximumImageSampleDistanceMaxValue_39(); }

  private native double GetMaximumImageSampleDistance_40();
  public double GetMaximumImageSampleDistance()
    { return GetMaximumImageSampleDistance_40(); }

  private native void SetFinalColorWindow_41(double id0);
  public void SetFinalColorWindow(double id0)
    { SetFinalColorWindow_41(id0); }

  private native double GetFinalColorWindow_42();
  public double GetFinalColorWindow()
    { return GetFinalColorWindow_42(); }

  private native void SetFinalColorLevel_43(double id0);
  public void SetFinalColorLevel(double id0)
    { SetFinalColorLevel_43(id0); }

  private native double GetFinalColorLevel_44();
  public double GetFinalColorLevel()
    { return GetFinalColorLevel_44(); }

  private native void SetMaxMemoryInBytes_45(int id0);
  public void SetMaxMemoryInBytes(int id0)
    { SetMaxMemoryInBytes_45(id0); }

  private native int GetMaxMemoryInBytes_46();
  public int GetMaxMemoryInBytes()
    { return GetMaxMemoryInBytes_46(); }

  private native void SetMaxMemoryFraction_47(double id0);
  public void SetMaxMemoryFraction(double id0)
    { SetMaxMemoryFraction_47(id0); }

  private native double GetMaxMemoryFractionMinValue_48();
  public double GetMaxMemoryFractionMinValue()
    { return GetMaxMemoryFractionMinValue_48(); }

  private native double GetMaxMemoryFractionMaxValue_49();
  public double GetMaxMemoryFractionMaxValue()
    { return GetMaxMemoryFractionMaxValue_49(); }

  private native double GetMaxMemoryFraction_50();
  public double GetMaxMemoryFraction()
    { return GetMaxMemoryFraction_50(); }

  private native void SetReportProgress_51(boolean id0);
  public void SetReportProgress(boolean id0)
    { SetReportProgress_51(id0); }

  private native boolean GetReportProgress_52();
  public boolean GetReportProgress()
    { return GetReportProgress_52(); }

  private native int IsRenderSupported_53(vtkRenderWindow id0,vtkVolumeProperty id1);
  public int IsRenderSupported(vtkRenderWindow id0,vtkVolumeProperty id1)
    { return IsRenderSupported_53(id0,id1); }

  private native void CreateCanonicalView_54(vtkRenderer id0,vtkVolume id1,vtkImageData id2,int id3,double id4[],double id5[]);
  public void CreateCanonicalView(vtkRenderer id0,vtkVolume id1,vtkImageData id2,int id3,double id4[],double id5[])
    { CreateCanonicalView_54(id0,id1,id2,id3,id4,id5); }

  private native void SetMaskInput_55(vtkImageData id0);
  public void SetMaskInput(vtkImageData id0)
    { SetMaskInput_55(id0); }

  private native long GetMaskInput_56();
  public vtkImageData GetMaskInput() {
    long temp = GetMaskInput_56();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetMaskType_57(int id0);
  public void SetMaskType(int id0)
    { SetMaskType_57(id0); }

  private native int GetMaskType_58();
  public int GetMaskType()
    { return GetMaskType_58(); }

  private native void SetMaskTypeToBinary_59();
  public void SetMaskTypeToBinary()
    { SetMaskTypeToBinary_59(); }

  private native void SetMaskTypeToLabelMap_60();
  public void SetMaskTypeToLabelMap()
    { SetMaskTypeToLabelMap_60(); }

  private native void SetMaskBlendFactor_61(double id0);
  public void SetMaskBlendFactor(double id0)
    { SetMaskBlendFactor_61(id0); }

  private native double GetMaskBlendFactorMinValue_62();
  public double GetMaskBlendFactorMinValue()
    { return GetMaskBlendFactorMinValue_62(); }

  private native double GetMaskBlendFactorMaxValue_63();
  public double GetMaskBlendFactorMaxValue()
    { return GetMaskBlendFactorMaxValue_63(); }

  private native double GetMaskBlendFactor_64();
  public double GetMaskBlendFactor()
    { return GetMaskBlendFactor_64(); }

  private native void SetRenderToImage_65(int id0);
  public void SetRenderToImage(int id0)
    { SetRenderToImage_65(id0); }

  private native int GetRenderToImage_66();
  public int GetRenderToImage()
    { return GetRenderToImage_66(); }

  private native void RenderToImageOn_67();
  public void RenderToImageOn()
    { RenderToImageOn_67(); }

  private native void RenderToImageOff_68();
  public void RenderToImageOff()
    { RenderToImageOff_68(); }

  private native void SetDepthImageScalarType_69(int id0);
  public void SetDepthImageScalarType(int id0)
    { SetDepthImageScalarType_69(id0); }

  private native int GetDepthImageScalarType_70();
  public int GetDepthImageScalarType()
    { return GetDepthImageScalarType_70(); }

  private native void SetDepthImageScalarTypeToUnsignedChar_71();
  public void SetDepthImageScalarTypeToUnsignedChar()
    { SetDepthImageScalarTypeToUnsignedChar_71(); }

  private native void SetDepthImageScalarTypeToUnsignedShort_72();
  public void SetDepthImageScalarTypeToUnsignedShort()
    { SetDepthImageScalarTypeToUnsignedShort_72(); }

  private native void SetDepthImageScalarTypeToFloat_73();
  public void SetDepthImageScalarTypeToFloat()
    { SetDepthImageScalarTypeToFloat_73(); }

  private native void SetClampDepthToBackface_74(int id0);
  public void SetClampDepthToBackface(int id0)
    { SetClampDepthToBackface_74(id0); }

  private native int GetClampDepthToBackface_75();
  public int GetClampDepthToBackface()
    { return GetClampDepthToBackface_75(); }

  private native void ClampDepthToBackfaceOn_76();
  public void ClampDepthToBackfaceOn()
    { ClampDepthToBackfaceOn_76(); }

  private native void ClampDepthToBackfaceOff_77();
  public void ClampDepthToBackfaceOff()
    { ClampDepthToBackfaceOff_77(); }

  private native void GetDepthImage_78(vtkImageData id0);
  public void GetDepthImage(vtkImageData id0)
    { GetDepthImage_78(id0); }

  private native void GetColorImage_79(vtkImageData id0);
  public void GetColorImage(vtkImageData id0)
    { GetColorImage_79(id0); }

  private native void Render_80(vtkRenderer id0,vtkVolume id1);
  public void Render(vtkRenderer id0,vtkVolume id1)
    { Render_80(id0,id1); }

  private native void GPURender_81(vtkRenderer id0,vtkVolume id1);
  public void GPURender(vtkRenderer id0,vtkVolume id1)
    { GPURender_81(id0,id1); }

  private native void ReleaseGraphicsResources_82(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_82(id0); }

  private native void GetReductionRatio_83(double id0[]);
  public void GetReductionRatio(double id0[])
    { GetReductionRatio_83(id0); }

  public vtkGPUVolumeRayCastMapper() { super(); }

  public vtkGPUVolumeRayCastMapper(long id) { super(id); }
  public native long   VTKInit();

}
